#ifndef BORD_H
#define BORD_H

#include <QList>

class Snake;
class QPoint;
class QRect;
class QPainter;

class Bord
{
public:

    virtual bool isColliding( Snake* aSnake );

    virtual bool isColliding( QPoint aPoint );

    virtual ~Bord();

    virtual void draw( QPainter* aPainter );

protected:

    Bord();

protected:

    //QList<QPoint> mWall;
    QList<QRect> mWall;


};

#endif // BORD_H
